diff --git a/.gitignore b/.gitignore
index fd228d9706..715fe23c42 100644
--- a/.gitignore
+++ b/.gitignore
@@ -56,10 +56,10 @@ paparazzi.sublime-workspace
/paparazzi
# /conf/
-/conf/conf.xml
+/conf/conf.xml~
/conf/conf.xml.20*
/conf/conf_personal.xml.20*
-/conf/control_panel.xml
+/conf/control_panel.xml~
/conf/control_panel.xml.20*
/conf/%gconf.xml
/conf/maps_data/*
diff --git a/conf/airframes/OPENUAS/openuas_eflite_t28.xml b/conf/airframes/OPENUAS/openuas_eflite_t28.xml
new file mode 100644
index 0000000000..19ecdb6042
--- /dev/null
+++ b/conf/airframes/OPENUAS/openuas_eflite_t28.xml
@@ -0,0 +1,751 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
\ No newline at end of file
diff --git a/conf/boards/px4fmu_4.0.makefile b/conf/boards/px4fmu_4.0.makefile
index 6cd756c5da..a9f32fc093 100644
--- a/conf/boards/px4fmu_4.0.makefile
+++ b/conf/boards/px4fmu_4.0.makefile
@@ -57,3 +57,9 @@ GPS_BAUD ?= B38400
# e.g.
#
ACTUATORS ?= actuators_pwm
+
+#
+# default External Current and Volt Sensor configuration
+#
+# ADC_CURRENT_SENSOR ?= ADC_3
+# ADC_VOLTAGE_SENSOR ?= ADC_2
diff --git a/conf/conf.xml b/conf/conf.xml
new file mode 120000
index 0000000000..8b45de80fa
--- /dev/null
+++ b/conf/conf.xml
@@ -0,0 +1 @@
+userconf/OPENUAS/openuas_conf.xml
\ No newline at end of file
diff --git a/conf/control_panel.xml b/conf/control_panel.xml
new file mode 120000
index 0000000000..99dae21217
--- /dev/null
+++ b/conf/control_panel.xml
@@ -0,0 +1 @@
+userconf/OPENUAS/openuas_control_panel.xml
\ No newline at end of file
diff --git a/conf/settings/OPENUAS/openuas_tuning_rc.xml b/conf/settings/OPENUAS/openuas_tuning_rc.xml
index ae3a8efcf5..f49b059e0f 100644
--- a/conf/settings/OPENUAS/openuas_tuning_rc.xml
+++ b/conf/settings/OPENUAS/openuas_tuning_rc.xml
@@ -23,8 +23,8 @@
-
-
+
+
diff --git a/conf/telemetry/OPENUAS/openuas_fixedwing_imu_rc.xml b/conf/telemetry/OPENUAS/openuas_fixedwing_imu_rc.xml
new file mode 100644
index 0000000000..ea2fd26463
--- /dev/null
+++ b/conf/telemetry/OPENUAS/openuas_fixedwing_imu_rc.xml
@@ -0,0 +1,124 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/conf/userconf/OPENUAS/openuas_conf.xml b/conf/userconf/OPENUAS/openuas_conf.xml
index 2329cebe00..ae4488e193 100644
--- a/conf/userconf/OPENUAS/openuas_conf.xml
+++ b/conf/userconf/OPENUAS/openuas_conf.xml
@@ -1,4 +1,15 @@
+
-
@@ -55,8 +53,6 @@
-
-
@@ -69,60 +65,140 @@
-
-
-
-
+
-
-
+
+
+
+
+
+
+
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
-
-
-
-
+
+
+
+
+
+
+
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
-
-
-
-
-
-
-
-
+
+
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
-
-
@@ -138,16 +214,112 @@
-
-
+
+
+
+
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -158,7 +330,134 @@
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -172,7 +471,55 @@
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
@@ -220,67 +567,14 @@
-
-
+
-
+
+
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
-
-
-
-
-
@@ -291,262 +585,28 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
-
-
-
-
-
-
-
+
-
-
-
-
-
-
-
-
-
-
-
-
+
-
-
-
-
-
-
-
-
-
-
-
-
+
+
-
+
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
@@ -565,11 +625,6 @@
-
-
-
-
-
@@ -584,64 +639,5 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
\ No newline at end of file
diff --git a/sw/airborne/arch/stm32/subsystems/radio_control/spektrum_arch.h b/sw/airborne/arch/stm32/subsystems/radio_control/spektrum_arch.h
index 99971b0bda..753deeaabe 100644
--- a/sw/airborne/arch/stm32/subsystems/radio_control/spektrum_arch.h
+++ b/sw/airborne/arch/stm32/subsystems/radio_control/spektrum_arch.h
@@ -52,8 +52,12 @@
#ifndef RADIO_YAW
#define RADIO_YAW 3
#endif
+#ifndef RADIO_GEAR
#define RADIO_GEAR 4
+#endif
+#ifndef RADIO_FLAP
#define RADIO_FLAP 5
+#endif
#define RADIO_AUX1 5
#define RADIO_AUX2 6
#define RADIO_AUX3 7
diff --git a/sw/airborne/boards/px4fmu_4.0.h b/sw/airborne/boards/px4fmu_4.0.h
index c2b29ac07a..6f12336450 100644
--- a/sw/airborne/boards/px4fmu_4.0.h
+++ b/sw/airborne/boards/px4fmu_4.0.h
@@ -6,12 +6,15 @@
/* PX4FMU_V4 a.k.a. Pixracer board has a 24MHz external clock and 168MHz internal. */
/* STM32F4 STM32F427VIT6 */
-#define EXT_CLK 24000000 //OK
-#define AHB_CLK 168000000 //OK
+#define EXT_CLK 24000000
+#define AHB_CLK 168000000
+
+//#define STM32F4 //to debug ADC on F4 does no work
+//#define ADC_SAMPLE_TIME ADC_SMPR_SMP_56CYC //to debug ADC on F4 does no work
+
+/* On PCB there is a Multicolor LED */
-/* On PCB Multicolor LED */
/* Red */
-//OK
#ifndef USE_LED_1
#define USE_LED_1 1
#endif
@@ -22,7 +25,6 @@
#define LED_1_AFIO_REMAP ((void)0)
/* Green */
-//OK
#ifndef USE_LED_2
#define USE_LED_2 1
#endif
@@ -33,7 +35,6 @@
#define LED_2_AFIO_REMAP ((void)0)
/* Blue */
-//OK
#ifndef USE_LED_3
#define USE_LED_3 1
#endif
@@ -49,6 +50,7 @@
/* UART SCHTUFFFF*/
/* -WiFi ESP Connector, it is just a serial port*/
+//TODO: Test
#define UART1_GPIO_AF GPIO_AF7
#define UART1_GPIO_PORT_RX GPIOB
#define UART1_GPIO_RX GPIO7
@@ -84,12 +86,12 @@
#define UART4_GPIO_PORT_TX GPIOA
#define UART4_GPIO_TX GPIO0
-/* Spektrum (only rx)*/
+/* e.g. for a Spektrum satellite receiver rx only)*/
#define UART6_GPIO_AF GPIO_AF8
#define UART6_GPIO_PORT_RX GPIOC
#define UART6_GPIO_RX GPIO7
-/* Serial Debugging Connector, not used with PPRZ, use JTAG, can be put to other good use */
+/* Serial Debugging Connector, not used with PPRZ as of now, use JTAG, can be put to other good use */
#define UART7_GPIO_AF GPIO_AF8
#define UART7_GPIO_PORT_RX GPIOE
#define UART7_GPIO_RX GPIO7
@@ -97,6 +99,7 @@
#define UART7_GPIO_TX GPIO8
/* Connector -FRS FrSky */
+//TODO: Test
#define UART8_GPIO_AF GPIO_AF8
#define UART8_GPIO_PORT_RX GPIOE
#define UART8_GPIO_RX GPIO0
@@ -104,24 +107,23 @@
#define UART8_GPIO_TX GPIO1
/* Soft binding Spektrum */
-//ok
+//TODO: Test and or FIXME:
#define RADIO_CONTROL_POWER_PORT GPIOE
#define RADIO_CONTROL_POWER_PIN GPIO4 //SPEKTRUM POWER
#define RADIO_CONTROL_POWER_ON gpio_clear // yes, inverted
#define RADIO_CONTROL_POWER_OFF gpio_set
-
+//A receiver on powered on 3.3v
#define PERIPHERAL3V3_ENABLE_PORT GPIOC //VDD_3V3_PERIPHERAL_EN
#define PERIPHERAL3V3_ENABLE_PIN GPIO5
#define PERIPHERAL3V3_ENABLE_ON gpio_set
#define PERIPHERAL3V3_ENABLE_OFF gpio_clear
/* Turn SBUS invert */
-//ok
+//TODO: Test
#define RC_POLARITY_GPIO_PORT GPIOC
#define RC_POLARITY_GPIO_PIN GPIO13
-//ok
#define SPEKTRUM_UART6_RCC RCC_USART6
#define SPEKTRUM_UART6_BANK GPIOC
#define SPEKTRUM_UART6_PIN GPIO7
@@ -133,7 +135,6 @@
/* SPI */
/* SPI1 for MPU and extra accel/gyro/mag */
-// OK
#define SPI1_GPIO_AF GPIO_AF5
#define SPI1_GPIO_PORT_MISO GPIOA
#define SPI1_GPIO_MISO GPIO6
@@ -143,7 +144,6 @@
#define SPI1_GPIO_SCK GPIO5
/* SPI2 for FRAM, connects to BARO */
-// OK
#define SPI2_GPIO_AF GPIO_AF5
#define SPI2_GPIO_PORT_MISO GPIOB
#define SPI2_GPIO_MISO GPIO14
@@ -164,8 +164,9 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
* SPI slave pin declaration
*/
-//So use best speced sensors as second or ref the other or determine it on task type?
+//So use best spec'd sensors as second or ref the other or determine it on task type?
/* EXTRA ACC_GYRO_CS on SPI1 ICM 20609-G*/
+// TODO: Make it useful
#define SPI_SELECT_SLAVE0_PORT GPIOC
#define SPI_SELECT_SLAVE0_PIN GPIO15
@@ -174,17 +175,16 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define SPI_SELECT_SLAVE1_PORT GPIOE
#define SPI_SELECT_SLAVE1_PIN GPIO15
-/* MDL
-#define SPI_SELECT_SLAVE1_PORT GPIOE
-#define SPI_SELECT_SLAVE1_PIN GPIO15 */
+/* MDL */
+// FIXME: Test n fix or emoveal
+//#define SPI_SELECT_SLAVE1_PORT GPIOE
+//#define SPI_SELECT_SLAVE1_PIN GPIO15
/* MPU_9250_CS on SPI1 */
-//OK
#define SPI_SELECT_SLAVE2_PORT GPIOC
#define SPI_SELECT_SLAVE2_PIN GPIO2
/* MS5611 BARO_CS on SPI2 - FRAM*/
-//OK
#define SPI_SELECT_SLAVE3_PORT GPIOD
#define SPI_SELECT_SLAVE3_PIN GPIO7
@@ -193,11 +193,13 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define SPI_SELECT_SLAVE4_PIN GPIO10
/* SPI3 NSS on microSD connector */
-//#define SPI_SELECT_SLAVE4_PORT GPIOA
-//#define SPI_SELECT_SLAVE4_PIN GPIO4
+//FIXME: not tested
+//#define SPI_SELECT_SLAVE5_PORT GPIOA
+//#define SPI_SELECT_SLAVE5_PIN GPIO4
/* SDIO to microSD card connector */
+//FIXME: Fix and test
#define SDIO_AF GPIO_AF12
#define SDIO_D0_PORT GPIOC
#define SDIO_D0_PIN GPIO8
@@ -218,11 +220,12 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#endif
#define USE_AD_TIM3 1
-
-// Internal ADC for battery
+// Internal ADC for voltage level measurement
+////FIXME: test and fix if still not working
#ifndef USE_ADC_1
#define USE_ADC_1 1
#endif
+
#if USE_ADC_1
#define AD1_1_CHANNEL 4 //ADC12_IN4
#define ADC_1 AD1_1
@@ -230,7 +233,8 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define ADC_1_GPIO_PIN GPIO4
#endif
-// External ADC for battery
+// Per default for the board to sense voltage level via external sensor on ADC
+//FIXME: test and fix if still not working
#ifndef USE_ADC_2
#define USE_ADC_2 1
#endif
@@ -241,8 +245,7 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define ADC_2_GPIO_PIN GPIO2
#endif
-
-// external current sens
+// Per default for the board to sense current via external sensor on ADC
#ifndef USE_ADC_3
#define USE_ADC_3 1
#endif
@@ -252,17 +255,24 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define ADC_3_GPIO_PORT GPIOA
#define ADC_3_GPIO_PIN GPIO3
#endif
-#define MilliAmpereOfAdc(adc)((float)adc) * (3.3f / 4096.0f) * (90.0f / 5.0f)
+#define MilliAmpereOfAdc(adc)((float)adc) * (3.3f / 4096.0f) * (90.0f / 5.0f) //TODO: test if valid
-/* allow to define ADC_CHANNEL_VSUPPLY in the airframe file*/
+/* Allow to define ADC_CHANNEL_VSUPPLY in the airframe file */
#ifndef ADC_CHANNEL_VSUPPLY
#define ADC_CHANNEL_VSUPPLY ADC_2
#endif
+/* Allow to define another ADC for Current measurement in the airframe file */
+#ifndef ADC_CHANNEL_CURRENT
+#define ADC_CHANNEL_CURRENT ADC_3
+#endif
+
+//??FT = Five-volt tolerant. In order to sustain a voltage higher than VDD+0.3 the internal pull-up/pull-down resistors must be disabled.
+//FIXME: Determine best stock values
#if USE_ADC_2
-#define DefaultVoltageOfAdc(adc) (0.00827*adc)
+#define DefaultVoltageOfAdc(adc) (0.004f * (float)adc) // FIXME: Value scale for a common PowerBrick
#else
-#define DefaultVoltageOfAdc(adc) (0.0021*adc) // scale internal vdd to 5V
+#define DefaultVoltageOfAdc(adc) (0.004f * (float)adc) // FIXME: Value scale internal vdd to 5V
#endif
/* I2C mapping */
@@ -270,12 +280,13 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define I2C1_GPIO_SCL GPIO8
#define I2C1_GPIO_SDA GPIO9
+//Onboard Barometer
#ifndef USE_BARO_BOARD
#define USE_BARO_BOARD 1
#endif
/* Another Magnetometer on board a HMC5983 not the one in the IMU 9250*/
-//TODO
+//FIXME: better default option for use of maybe fuse data
#ifndef USE_MAGNETOMETER_B
#define USE_MAGNETOMETER_B 0
#endif
@@ -290,6 +301,10 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define PWM_USE_TIM1 1
#define PWM_USE_TIM4 1
+
+//TODO: ifdef USE_SERVO6 for PPM out to e.g. servo extender board ...
+// Basically a inter mcu Extra device;)
+
#define USE_PWM1 1
#define USE_PWM2 1
#define USE_PWM3 1
@@ -297,7 +312,7 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define USE_PWM5 1
#define USE_PWM6 1
-/* -ESC Servo 1 */
+/* Servo 1 */
#if USE_PWM1
#define PWM_SERVO_1 0
#define PWM_SERVO_1_TIMER TIM1
@@ -310,7 +325,7 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define PWM_SERVO_1_OC_BIT 0
#endif
-/* -ESC Servo 2 */
+/* Servo 2 */
#if USE_PWM2
#define PWM_SERVO_2 1
#define PWM_SERVO_2_TIMER TIM1
@@ -323,7 +338,7 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define PWM_SERVO_2_OC_BIT 0
#endif
-/* -ESC Servo 3 */
+/* Servo 3 */
#if USE_PWM3
#define PWM_SERVO_3 2 //#define PWM_SERVO_3_IDX 2
#define PWM_SERVO_3_TIMER TIM1
@@ -336,7 +351,7 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define PWM_SERVO_3_OC_BIT 0
#endif
-/* -ESC Servo 4 */
+/* Servo 4 */
#if USE_PWM4
#define PWM_SERVO_4 3
#define PWM_SERVO_4_TIMER TIM1
@@ -349,7 +364,7 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define PWM_SERVO_4_OC_BIT 0
#endif
-/* -ESC Servo 5 */
+/* Servo 5 */
#if USE_PWM5
#define PWM_SERVO_5 4
#define PWM_SERVO_5_TIMER TIM4
@@ -362,7 +377,7 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define PWM_SERVO_5_OC_BIT 0
#endif
-/* -ESC Servo 6 */
+/* Servo 6 */
#if USE_PWM6
#define PWM_SERVO_6 5
#define PWM_SERVO_6_TIMER TIM4
@@ -379,7 +394,7 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define PWM_TIM4_CHAN_MASK (PWM_SERVO_5_OC_BIT|PWM_SERVO_6_OC_BIT)
/* Buzzer (A.k.a. Alarm) */
-
+//TODO: Test
#if USE_BUZZER
#define PWM_BUZZER
#define PWM_BUZZER_TIMER TIM2
@@ -393,6 +408,4 @@ When a read-operation of an RTD resistance data register occurs, DRDY returns hi
#define PWM_BUZZER_OC_BIT 0
#endif
-
-
#endif /* CONFIG_PX4FMU_4_0_H */
diff --git a/sw/ext/opencv_bebop b/sw/ext/opencv_bebop
index 365cf9fe2c..4e8ced8085 160000
--- a/sw/ext/opencv_bebop
+++ b/sw/ext/opencv_bebop
@@ -1 +1 @@
-Subproject commit 365cf9fe2cf4abc04c5b982feb54d04caa19fefd
+Subproject commit 4e8ced80856b60d887b16c8211e34aebae581808
diff --git a/sw/ground_segment/tmtc/Makefile b/sw/ground_segment/tmtc/Makefile
index 777114e62b..8770869cd7 100644
--- a/sw/ground_segment/tmtc/Makefile
+++ b/sw/ground_segment/tmtc/Makefile
@@ -38,7 +38,7 @@ SERVERCMO = server_globals.cmo aircraft.cmo wind.cmo airprox.cmo kml.cmo fw_serv
SERVERCMX = $(SERVERCMO:.cmo=.cmx)
-all: link server messages settings ivy_tcp_aircraft ivy_tcp_controller broadcaster ivy2udp ivy2serial ivy_serial_bridge app_server ivy2nmea
+all: link server messages settings ivy_tcp_aircraft ivy_tcp_controller broadcaster ivy2udp ivy2serial ivy_serial_bridge app_server ivy2nmea gpsd2ivy
opt: server.opt
diff --git a/sw/airborne/modules/switching/auto1_commands.c b/sw/airborne/modules/switching/auto1_commands.c
index 80a95ce7b1..91899fba8b 100644
--- a/sw/airborne/modules/switching/auto1_commands.c
+++ b/sw/airborne/modules/switching/auto1_commands.c
@@ -29,11 +29,59 @@ void periodic_auto1_commands(void)
{
// Copy Radio commands in AUTO1
if (autopilot_get_mode() == AP_MODE_AUTO1) {
#ifdef COMMAND_HATCH
#ifndef RADIO_HATCH
#error auto1_commands COMMAND_HATCH needs RADIO_HATCH channel
#endif
- imcu_set_command(COMMAND_HATCH, imcu_get_radio(RADIO_HATCH));
+ imcu_set_command(COMMAND_GEAR, imcu_get_radio(RADIO_GEAR));
+#endif
+#ifdef COMMAND_FLAP
+#ifndef RADIO_FLAP
+#error auto1_commands COMMAND_FLAP needs RADIO_FLAP channel
+#endif
+ imcu_set_command(COMMAND_FLAP, imcu_get_radio(RADIO_FLAP));
+#endif
+#ifdef COMMAND_AUX1
+#ifndef RADIO_AUX1
+#error auto1_commands COMMAND_AUX1 needs RADIO_AUX1 channel
+#endif
+ imcu_set_command(COMMAND_AUX1, imcu_get_radio(RADIO_AUX1));
+#endif
+#ifdef COMMAND_AUX2
+#ifndef RADIO_AUX2
+#error auto1_commands COMMAND_AUX2 needs RADIO_AUX2 channel
+#endif
+ imcu_set_command(COMMAND_AUX2, imcu_get_radio(RADIO_AUX2));
+#endif
+#ifdef COMMAND_AUX3
+#ifndef RADIO_AUX3
+#error auto1_commands COMMAND_AUX1 needs RADIO_AUX3 channel
+#endif
+ imcu_set_command(COMMAND_AUX3, imcu_get_radio(RADIO_AUX3));
+#endif
+#ifdef COMMAND_AUX4
+#ifndef RADIO_AUX4
+#error auto1_commands COMMAND_AUX4 needs RADIO_AUX4 channel
+#endif
+ imcu_set_command(COMMAND_AUX4, imcu_get_radio(RADIO_AUX4));
+#endif
+#ifdef COMMAND_AUX5
+#ifndef RADIO_AUX5
+#error auto1_commands COMMAND_AUX5 needs RADIO_AUX5 channel
+#endif
+ imcu_set_command(COMMAND_AUX5, imcu_get_radio(RADIO_AUX5));
+#endif
+#ifdef COMMAND_AUX6
+#ifndef RADIO_AUX6
+#error auto1_commands COMMAND_AUX6 needs RADIO_AUX6 channel
+#endif
+ imcu_set_command(COMMAND_AUX6, imcu_get_radio(RADIO_AUX6));
+#endif
+#ifdef COMMAND_AUX7
+#ifndef RADIO_AUX7
+#error auto1_commands COMMAND_AUX7 needs RADIO_AUX7 channel
+#endif
+ imcu_set_command(COMMAND_AUX7, imcu_get_radio(RADIO_AUX7));
#endif
#ifdef COMMAND_BRAKE
#ifndef RADIO_BRAKE
@@ -41,11 +89,11 @@ void periodic_auto1_commands(void)
#endif
imcu_set_command(COMMAND_BRAKE, imcu_get_radio(RADIO_BRAKE));
#endif
-#ifdef COMMAND_FLAPS
-#ifndef RADIO_FLAPS
-#error auto1_commands COMMAND_FLAPS needs RADIO_FLAPS channel
+#ifdef COMMAND_HATCH
+#ifndef RADIO_HATCH
+#error auto1_commands COMMAND_HATCH needs RADIO_HATCH channel
#endif
- imcu_set_command(COMMAND_FLAPS, imcu_get_radio(RADIO_FLAPS));
+ imcu_set_command(COMMAND_HATCH, imcu_get_radio(RADIO_HATCH));
#endif
}
}
@@ -29,11 +29,59 @@ void periodic_auto1_commands(void)
// Copy Radio commands in AUTO1
if (autopilot_get_mode() == AP_MODE_AUTO1) {
-#ifdef COMMAND_HATCH
-#ifndef RADIO_HATCH
-#error auto1_commands COMMAND_HATCH needs RADIO_HATCH channel
+#ifdef COMMAND_GEAR
+#ifndef RADIO_GEAR
+#error auto1_commands COMMAND_GEAR needs RADIO_GEAR channel
#endif